##  Overview
This guide shows you how to create your first diagram in SAP LeanIX and describes the editor basics. You’ll:
  * Create a new diagram
  * Open the diagram editor
  * Understand the editor layout
  * Add basic elements such as shapes and fact sheets


Use this page as a starting point if you haven't worked with diagrams in LeanIX before.
